==> pywebview-2.0.1.tar.gz: pywebview-2.0.1/webview/js/api.py <==
src = """
window.pywebview = {
    _createApi: function(funcList) {
        for (var i = 0; i < funcList.length; i++) {
            window.pywebview.api[funcList[i]] = (function (funcName) {
                return function(params) {
                    var promise = new Promise(function(resolve, reject) {
                        window.pywebview._checkValue(funcName, resolve);
                    });
                    window.pywebview._bridge.call(funcName, JSON.stringify(params));

                    return promise;
                }
            })(funcList[i])

            window.pywebview._returnValues[funcList[i]] = {
                isSet: false,
                value: undefined,
            }
        }
    },
    _bridge: {
        call: function (func_name, params) {
            if (window.qt) {
                new QWebChannel(qt.webChannelTransport, function(channel) {
                  channel.objects.external.call(func_name, params);
                });
            } else if (window.external) {
                return window.external.call(func_name, params);
            }
        }
    },

    _checkValue: function(funcName, resolve) {
         var check = setInterval(function () {
            var returnObj = window.pywebview._returnValues[funcName];

            if (returnObj.isSet) {
                returnObj.isSet = false;
                try {
                    resolve(JSON.parse(returnObj.value.replace(/\\n/, '\\\\n')));
                } catch(e) {
                    resolve(returnObj.value);
                }

                clearInterval(check);
            }
         }, 100)
    },
    api: {},
    _returnValues: {},

}
window.pywebview._createApi(%s);
"""

==> pywebview-3.0.tar.gz: pywebview-3.0/webview/js/api.py <==
src = """
window.pywebview = {
    token: '%s',
    _createApi: function(funcList) {
        for (var i = 0; i < funcList.length; i++) {
            window.pywebview.api[funcList[i]] = (function (funcName) {
                return function(params) {
                    var promise = new Promise(function(resolve, reject) {
                        window.pywebview._checkValue(funcName, resolve);
                    });
                    window.pywebview._bridge.call(funcName, JSON.stringify(params));
                    console.log(funcName);
                    return promise;
                }
            })(funcList[i])

            window.pywebview._returnValues[funcList[i]] = {
                isSet: false,
                value: undefined,
            }
        }
    },
    _bridge: {
        call: function (funcName, params) {
            switch(window.pywebview.platform) {
                case 'mshtml':
                case 'cef':
                case 'qtwebkit':
                    return window.external.call(funcName, params);
                case 'edgehtml':
                    return window.external.notify(JSON.stringify([funcName, params]));
                case 'cocoa':
                    return window.webkit.messageHandlers.jsBridge.postMessage(JSON.stringify([funcName, params]));
                case 'qtwebengine':
                    new QWebChannel(qt.webChannelTransport, function(channel) {
                        channel.objects.external.call(funcName, params);
                    });
                    break;
            }
        }
    },

    _checkValue: function(funcName, resolve) {
         var check = setInterval(function () {
            var returnObj = window.pywebview._returnValues[funcName];
            if (returnObj.isSet) {
                returnObj.isSet = false;
                try {
                    resolve(JSON.parse(returnObj.value.replace(/\\n/, '\\\\n')));
                } catch(e) {
                    resolve(returnObj.value);
                }

                clearInterval(check);
            }
         }, 100)
    },
    platform: '%s',
    api: {},
    _returnValues: {}
}

window.pywebview._createApi(%s);
"""
